
Annexe
=======

File : capital-qa.yaml
------------------------
.. literalinclude:: ../../../../examples/user/templates/capital-qa.yaml
    :language: yaml
    :caption: File is available at `capital-qa.yaml <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/templates/capital-qa.yaml>`_ on GitHub.

File : synth-animal.yaml
-------------------------
.. literalinclude:: ../../../../examples/user/templates/synth-animal.yaml
    :language: yaml
    :caption: File is available at `synth-animal.yaml <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/templates/synth-animal.yaml>`_ on GitHub.

File : penguins.csv
---------------------
.. literalinclude:: ../../../../examples/user/assets/penguins.csv
    :language: text
    :lines: 1-6,340-
    :caption: File is available at `penguins.csv <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/assets/penguins.csv>`_ on GitHub.

File : instruction.yaml
-------------------------
.. literalinclude:: ../../../../examples/user/templates/instruction.yaml
    :language: yaml
    :lines: 2-
    :caption: File is available at `instruction.yaml <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/templates/instruction.yaml>`_ on GitHub.

File : tasks.jsonl
-------------------------
.. literalinclude:: ../../../../examples/user/assets/seed_tasks.jsonl
    :language: json
    :lines: 0-6
    :caption: File is available at `tasks.jsonl <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/assets/seed_tasks.jsonl>`_ on GitHub.
